/*
 * IIIF Tsukushi Viewer v2.0
 * http://codh.rois.ac.jp/software/iiif-tsukushi-viewer/
 *
 * Copyright 2024 Center for Open Data in the Humanities, Research Organization of Information and Systems
 * Released under the MIT license
 *
 * Core contributor: Jun HOMMA (@2SC1815J)
 *
 * Licenses of open source libraries, see acknowledgements.txt
 */
var iiifViewer = (function() {
    var config = {
        title: [
            {
                '@language': 'ja',
                '@value': '<span class="icp_navbar_brand_logo"></span>IIIF Tsukushi Viewer（試行版）'
            },
            {
                '@language': 'en',
                '@value': '<span class="icp_navbar_brand_logo"></span>IIIF Tsukushi Viewer (Experimental Version)'
            }
        ],
        trustedUrlPrefixes: ['https://', 'http://'],
        doc: {
            aboutUrl: 'http://codh.rois.ac.jp/software/iiif-tsukushi-viewer/'
        },
        //Tsukushi Content Service
        contentService: {
            endpointUrl: 'http://codh.rois.ac.jp/tsukushi/iiif-content/canvas-text',
            label: 'Tsukushi Content Service',
            description: [
                {
                    '@language': 'en',
                    '@value': 'A web service that provides the functionality to register and search text in the basic unit of the IIIF as a RESTful API. Please refer to <a href="/tsukushi/#tsukushi-content-service">Tsukushi Content Service</a> for details.'
                },
                {
                    '@language': 'ja',
                    '@value': 'IIIFの基本単位でテキストを登録し検索する機能をRESTful APIとして提供するウェブサービスです。詳しくは<a href="/tsukushi/#tsukushi-content-service">Tsukushi Content Service</a>をご覧下さい。'
                }
            ]
        },
        //Tsukushi Chat Service
        chatService: {
            endpointUrl: 'https://mp.ex.nii.ac.jp/tsukushi/chat',
            label: 'Tsukushi Chat Service',
            description: [
                {
                    '@language': 'en',
                    '@value': 'A web service that provides functionality to convey prompts received from users to a large-scale language model and deliver the answers to users as a JSON-RPC API. Please refer to <a href="/tsukushi/#tsukushi-chat-service">Tsukushi Chat Service</a> for details and <a href="/tsukushi/terms/">Privacy Policy / Terms of Use</a> when using this service.'
                },
                {
                    '@language': 'ja',
                    '@value': '利用者から受け取ったプロンプトを大規模言語モデルに伝え、その回答を利用者に届けるための機能をJSON-RPC APIとして提供するウェブサービスです。詳しくは<a href="/tsukushi/#tsukushi-chat-service">Tsukushi Chat Service</a>を、また本サービスの利用にあたっては、<a href="/tsukushi/terms/">プライバシーポリシー／利用規約</a>をご覧ください。'
                }
            ],
            chatMethod: {
                book: {
                    method: 'book:chat',
                    params: {
                        prompt: '',
                        manifest: ''
                    }
                },
                page: {
                    method: 'text:chat',
                    params: {
                        prompt: '',
                        content: ''
                    }
                },
                region: {
                    method: 'image:chat',
                    params: {
                        prompt: '',
                        image: ''
                    }
                }
            },
            promptLibrary: {
                book: [
                    {
                        method: 'book:summarize',
                        label: [
                            {
                                '@language': 'en',
                                '@value': 'Summarize'
                            },
                            {
                                '@language': 'ja',
                                '@value': '要約する'
                            }
                        ],
                        text: [
                            {
                                '@language': 'en',
                                '@value': 'Summarize the book'
                            },
                            {
                                '@language': 'ja',
                                '@value': '本全体の内容をまとめて'
                            }
                        ],
                        params: {
                            manifest: ''
                        }
                    }
                ],
                page: [
                    {
                        method: 'text:summarize',
                        label: [
                            {
                                '@language': 'en',
                                '@value': 'Summarize'
                            },
                            {
                                '@language': 'ja',
                                '@value': '要約する'
                            }
                        ],
                        text: [
                            {
                                '@language': 'en',
                                '@value': 'Summarize the page list'
                            },
                            {
                                '@language': 'ja',
                                '@value': 'ページリストの内容を要約して'
                            }
                        ],
                        params: {
                            content: ''
                        }
                    },
                    {
                        method: 'text:translate',
                        label: [
                            {
                                '@language': 'en',
                                '@value': 'Translate'
                            },
                            {
                                '@language': 'ja',
                                '@value': '翻訳する'
                            }
                        ],
                        text: [
                            {
                                '@language': 'en',
                                '@value': 'Translate the page list to English'
                            },
                            {
                                '@language': 'ja',
                                '@value': 'ページリストを英語に翻訳して'
                            }
                        ],
                        params: {
                            content: ''
                        }
                    }
                ],
                region: [
                    {
                        method: 'image:describe',
                        label: [
                            {
                                '@language': 'en',
                                '@value': 'Describe'
                            },
                            {
                                '@language': 'ja',
                                '@value': '記述する'
                            }
                        ],
                        text: [
                            {
                                '@language': 'en',
                                '@value': 'Describe the image'
                            },
                            {
                                '@language': 'ja',
                                '@value': '画像の内容を記述して'
                            }
                        ],
                        params: {
                            image: ''
                        }
                    }
                ]
            },
            models: {
                'claude-3-5-sonnet': {
                    label: 'claude-3-5-sonnet☆☆☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Use the paid APIs provided by Anthropic. There is a limit of a maximum of 10 uses per 24 hours for all paid APIs combined. [ <a href="/tsukushi/ai-chat/#claude-3-5-sonnet" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Anthropicが提供する課金APIを利用します。すべての課金APIを合計して、24時間あたり最大10回の利用回数制限があります。[ <a href="/tsukushi/ai-chat/#claude-3-5-sonnet" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    hasQuota: true,
                    params: {
                        'temperature': {
                            label: 'Temperature',
                            default: '0.2',
                            isPersistent: true,
                            description: [
                                {
                                    '@language': 'en',
                                    '@value': 'Temperature (0.0-1.0) controls the randomness. A larger value returns more diverse answer. This setting is preserved in a browser.'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': 'Temperature (0.0-1.0)はランダム性を制御します。値を大きくすると、回答の多様性が高まります。この設定はブラウザに保存されます。'
                                },
                            ]
                        }
                    },
                    features: {
                        'performance': 'performance_priority',
                        'language': 'multilingual'
                    }
                },
                'gpt-4o': {
                    label: 'gpt-4o☆☆☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Use the paid APIs provided by OpenAI. There is a limit of a maximum of 10 uses per 24 hours for all paid APIs combined. [ <a href="/tsukushi/ai-chat/#gpt-4o" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'OpenAIが提供する課金APIを利用します。すべての課金APIを合計して、24時間あたり最大10回の利用回数制限があります。[ <a href="/tsukushi/ai-chat/#gpt-4o" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    hasQuota: true,
                    params: {
                        'temperature': {
                            label: 'Temperature',
                            default: '0.2',
                            isPersistent: true,
                            description: [
                                {
                                    '@language': 'en',
                                    '@value': 'Temperature (0.0-1.0) controls the randomness. A larger value returns more diverse answer. This setting is preserved in a browser.'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': 'Temperature (0.0-1.0)はランダム性を制御します。値を大きくすると、回答の多様性が高まります。この設定はブラウザに保存されます。'
                                },
                            ]
                        }
                    },
                    features: {
                        'performance': 'performance_priority',
                        'language': 'multilingual'
                    }
                },
                'gemma2': {
                    label: 'gemma2☆☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Gemma 2 released from Google DeepMind is a multilingual language model. [ <a href="/tsukushi/ai-chat/#gemma2" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Google DeepMindが公開するGemma 2は、多言語の言語モデルです。 [ <a href="/tsukushi/ai-chat/#gemma2" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'multilingual'
                    }
                },
                'qwen2': {
                    label: 'qwen2☆☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Qwen2 released from Alibaba is a multilingual language model. [ <a href="/tsukushi/ai-chat/#qwen2" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Alibabaが公開するQwen2は、多言語の言語モデルです。 [ <a href="/tsukushi/ai-chat/#qwen2"  target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'multilingual'
                    }
                },
                'elyza': {
                    label: 'elyza☆☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Llama-3-ELYZA-JP-8B released by Elyza is a Japanese-centric language model. [ <a href="/tsukushi/ai-chat/#elyza" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Elyzaが公開するLlama-3-ELYZA-JP-8Bは、日本語中心の言語モデルです。[ <a href="/tsukushi/ai-chat/#elyza" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'japanese_centric'
                    }
                },
                'phi3': {
                    label: 'phi-3☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Phi-3 released from Microsoft is an English-centric language model. [ <a href="/tsukushi/ai-chat/#phi3" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Microsoftが公開するPhi-3は、英語中心の言語モデルです。[ <a href="/tsukushi/ai-chat/#phi3" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'english_centric'
                    }
                },
                'llm-jp': {
                    label: 'llm-jp☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'LLM-jp-13B-v2.0 released from the LLM Study Group is a Japanese-centric language model. [ <a href="/tsukushi/ai-chat/#llm-jp" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'LLM勉強会が公開するLLM-jp-13B-v2.0は、日本語中心の言語モデルです。[ <a href="/tsukushi/ai-chat/#llm-jp" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'japanese_centric'
                    }
                },
                'mistral': {
                    label: 'mistral☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Mistral 7B released from Mistral AI is an English-centric language model. <a href="/tsukushi/ai-chat/#mistral" target="_blank">Detailed Information</a>.'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Mistral AIが公開するMistral 7Bは、英語中心の言語モデルです。[ <a href="/tsukushi/ai-chat/#mistral" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'english_centric'
                    }
                },
                'llama3': {
                    label: 'llama3☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Llama3 released from Meta is an English-centric language model. [ <a href="/tsukushi/ai-chat/#llama3" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Metaが公開するLlama3は、英語中心の言語モデルです。[ <a href="/tsukushi/ai-chat/#llama3" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'english_centric'
                    }
                },
                'aya': {
                    label: 'aya☆',
                    description: [
                        {
                            '@language': 'en',
                            '@value': 'Aya released from Cohere is a multilingual language model. [ <a href="/tsukushi/ai-chat/#aya" target="_blank">Detailed Information</a> ]'
                        },
                        {
                            '@language': 'ja',
                            '@value': 'Cohereが公開するAyaは、多言語の言語モデルです。[ <a href="/tsukushi/ai-chat/#aya" target="_blank">詳細情報</a> ]'
                        }
                    ],
                    params: {
                    },
                    features: {
                        'performance': 'usage_priority',
                        'language': 'multilingual'
                    }
                }
            },
            params: {
                'refPages': {
                    label: [
                        {
                            '@language': 'en',
                            '@value': 'Number of reference pages'
                        },
                        {
                            '@language': 'ja',
                            '@value': '参考ページ数'
                        }
                    ],
                    default: '5',
                    placeholder: [
                        {
                            '@language': 'en',
                            '@value': 'Enter a number'
                        },
                        {
                            '@language': 'ja',
                            '@value': '数字を入力'
                        }
                    ]
                }
            },
            modelFeatures: {
                'performance': {
                    label: [
                        {
                            '@language': 'en',
                            '@value': 'Filter by usage pattern'
                        },
                        {
                            '@language': 'ja',
                            '@value': '利用パターンで絞り込み'
                        }
                    ],
                    options: {
                        'performance_priority': {
                            label: [
                                {
                                    '@language': 'en',
                                    '@value': 'Priortize performance'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': '高性能優先'
                                }
                            ]
                        },
                        'usage_priority': {
                            label: [
                                {
                                    '@language': 'en',
                                    '@value': 'Priortize number of use'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': '利用回数優先'
                                }
                            ]
                        }
                    }
                },
                'language': {
                    label: [
                        {
                            '@language': 'en',
                            '@value': 'Filter by language'
                        },
                        {
                            '@language': 'ja',
                            '@value': '言語で絞り込み'
                        }
                    ],
                    options: {
                        'multilingual': {
                            label: [
                                {
                                    '@language': 'en',
                                    '@value': 'Multilingual'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': '多言語'
                                }
                            ]
                        },
                        'japanese_centric': {
                            label: [
                                {
                                    '@language': 'en',
                                    '@value': 'Japanese-centric'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': '日本語中心'
                                }
                            ]
                        },
                        'english_centric': {
                            label: [
                                {
                                    '@language': 'en',
                                    '@value': 'English-centric'
                                },
                                {
                                    '@language': 'ja',
                                    '@value': '英語中心'
                                }
                            ]
                        }
                    }
                }
            }
        },
        //IIIF Tsukushi Viewer
        tsukushiViewer: {
            message: {
                showOnLoaded: true,
                title: [
                    {
                        '@language': 'en',
                        '@value': 'Note on the Usage of Generative AI'
                    },
                    {
                        '@language': 'ja',
                        '@value': '生成AIの利用に関する注意事項'
                    }
                ],
                description: [
                    {
                        '@language': 'en',
                        '@value': 'The output of Generative AI should be verified by the original text or appropriate references.<br/>Some models have a limit of a maximum number of uses per 24 hours.'
                    },
                    {
                        '@language': 'ja',
                        '@value': '生成AIの出力内容については、原文や適切な情報源で確認してください。<br/>一部のモデルには、24時間あたりの利用回数制限があります。'
                    }
                ]
            }
        }
    };
    return IIIFTsukushiViewer(config);
})();